<?php
session_start();

define('DB_HOST', 'localhost'); //数据库主机地址
define('DB_NAME', 'floraease'); //数据库名称
define('DB_USER', 'root'); //数据库用户名
define('DB_PASS', 'root'); //数据库密码
define('title', '鲜花门店发展管理系统（FloraEase）'); //系统名称

try {
    $pdo = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME . ";charset=utf8mb4",
        DB_USER,
        DB_PASS,
        [
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC
        ]
    );
} catch (PDOException $e) {
    die("数据库连接失败: " . $e->getMessage());
}

/**
 * 记录操作日志
 * @param string $operation 操作描述
 * @return bool 是否记录成功
 */
function record_log($operation)
{
    global $pdo;

    $user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
    $username = isset($_SESSION['username']) ? $_SESSION['username'] : null;
    $ip = get_client_ip();

    try {
        $stmt = $pdo->prepare("INSERT INTO sys_logs (user_id, username, operation, ip) VALUES (?, ?, ?, ?)");
        return $stmt->execute([$user_id, $username, $operation, $ip]);
    } catch (PDOException $e) {
        // 日志记录失败，但不影响主程序运行
        error_log("记录日志失败: " . $e->getMessage());
        return false;
    }
}

/**
 * 获取客户端IP地址
 * @return string 客户端IP地址
 */
function get_client_ip()
{
    if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
        $ip = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
    } else {
        $ip = $_SERVER['REMOTE_ADDR'];
    }
    return $ip;
}

/**
 * 检查当前用户是否有指定权限
 * @param string $permission 权限标识符，可以是点分隔的多级权限
 * @return bool 是否有权限
 */
function has_permission($permission)
{
    // 未登录用户没有任何权限
    if (!isset($_SESSION['user_id']) || !isset($_SESSION['role_id'])) {
        return false;
    }

    // 系统管理员拥有所有权限
    if ($_SESSION['role_id'] == 1) {
        return true;
    }

    // 获取用户角色权限
    $permissions = get_role_permissions($_SESSION['role_id']);
    if (!$permissions) {
        return false;
    }

    // 检查是否有all权限
    if (isset($permissions['all']) && $permissions['all'] === true) {
        return true;
    }

    // 检查具体权限
    return check_specific_permission($permissions, $permission);
}

/**
 * 获取角色权限
 * @param int $role_id 角色ID
 * @return array|null 权限数组或null
 */
function get_role_permissions($role_id)
{
    global $pdo;

    try {
        $stmt = $pdo->prepare("SELECT permissions FROM sys_roles WHERE id = ?");
        $stmt->execute([$role_id]);
        $role = $stmt->fetch();

        if ($role && !empty($role['permissions'])) {
            return json_decode($role['permissions'], true);
        }
        return null;
    } catch (PDOException $e) {
        error_log("获取角色权限失败: " . $e->getMessage());
        return null;
    }
}

/**
 * 检查特定权限
 * @param array $permissions 权限数组
 * @param string $permission 待检查的权限
 * @return bool 是否有权限
 */
function check_specific_permission($permissions, $permission)
{
    // 直接权限检查
    if (isset($permissions[$permission]) && $permissions[$permission] === true) {
        return true;
    }

    // 多级权限检查（如order.view）
    $parts = explode('.', $permission);
    if (count($parts) > 1) {
        $parent = $parts[0];
        $child = $parts[1];

        // 如果有父级全部权限
        if (isset($permissions[$parent]) && $permissions[$parent] === true) {
            return true;
        }

        // 如果有父级特定子权限
        if (
            isset($permissions[$parent]) && is_array($permissions[$parent]) &&
            isset($permissions[$parent][$child]) && $permissions[$parent][$child] === true
        ) {
            return true;
        }
    }

    return false;
}

/**
 * 检查当前用户是否有权限，如无权限则跳转到无权限页面
 * @param string $permission 权限标识符
 */
function check_permission_or_die($permission)
{
    if (!has_permission($permission)) {
        // 记录未授权访问日志
        record_log("未授权访问: " . $permission);

        // 跳转到无权限页面
        header("Location: no_permission.php");
        exit;
    }
}
