<?php
// order/status.php - 订单状态管理
session_start();
require_once '../database_config.php';

// 检查权限
check_permission_or_die('order.view');

// 处理操作
$action = isset($_GET['action']) ? $_GET['action'] : (isset($_POST['action']) ? $_POST['action'] : 'list');
$id = isset($_GET['id']) ? intval($_GET['id']) : (isset($_POST['id']) ? intval($_POST['id']) : 0);
$alert = '';

// 更新订单状态
if ($action == 'update' && $id > 0 && has_permission('order.edit')) {
    $new_status = isset($_POST['status']) ? intval($_POST['status']) : 0;
    $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

    try {
        // 获取订单当前状态
        $stmt = $pdo->prepare("SELECT status FROM orders WHERE id = ?");
        $stmt->execute([$id]);
        $order = $stmt->fetch();

        if (!$order) {
            throw new Exception("订单不存在");
        }

        // 验证状态变更的合法性
        $valid_transitions = [
            1 => [2, 5],        // 待付款 -> 已付款, 已取消
            2 => [3, 6],        // 已付款 -> 待配送, 退款中
            3 => [4, 6],        // 待配送 -> 已完成, 退款中
            6 => [2, 7]         // 退款中 -> 已付款(取消退款), 已退款
        ];

        if (!isset($valid_transitions[$order['status']]) || !in_array($new_status, $valid_transitions[$order['status']])) {
            throw new Exception("无效的状态变更");
        }

        // 更新订单状态
        $stmt = $pdo->prepare("UPDATE orders SET status = ?, remark = ?, update_time = NOW() WHERE id = ?");
        $result = $stmt->execute([$new_status, $remark, $id]);

        if ($result) {
            // 记录日志
            record_log("更新订单状态 ID:{$id} 从状态:{$order['status']} 到状态:{$new_status}");
            $alert = '<div class="alert alert-success">订单状态更新成功</div>';
            $action = 'list';
        } else {
            throw new Exception("更新失败");
        }
    } catch (Exception $e) {
        $alert = '<div class="alert alert-danger">更新订单状态失败：' . $e->getMessage() . '</div>';
    }
}

// 获取订单详情（用于编辑状态）
if ($action == 'edit' && $id > 0) {
    $stmt = $pdo->prepare("
        SELECT o.*, m.name as member_name, s.name as store_name 
        FROM orders o 
        LEFT JOIN members m ON o.member_id = m.id
        LEFT JOIN stores s ON o.store_id = s.id
        WHERE o.id = ?
    ");
    $stmt->execute([$id]);
    $order = $stmt->fetch();

    if (!$order) {
        $alert = '<div class="alert alert-danger">订单不存在</div>';
        $action = 'list';
    }
}

// 获取所有订单（分组按状态）
if ($action == 'list') {
    $sql = "
        SELECT 
            o.status,
            COUNT(*) as count
        FROM orders o
        GROUP BY o.status
        ORDER BY o.status
    ";
    $stmt = $pdo->query($sql);
    $status_counts = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);

    // 获取最近状态变更的订单
    $sql = "
        SELECT o.*, m.name as member_name
        FROM orders o
        LEFT JOIN members m ON o.member_id = m.id
        ORDER BY o.update_time DESC
        LIMIT 10
    ";
    $stmt = $pdo->query($sql);
    $recent_orders = $stmt->fetchAll();
}

// 获取订单状态文本
function get_status_text($status)
{
    $status_array = [
        1 => '待付款',
        2 => '已付款',
        3 => '待配送',
        4 => '已完成',
        5 => '已取消',
        6 => '退款中',
        7 => '已退款'
    ];
    return isset($status_array[$status]) ? $status_array[$status] : '未知状态';
}

// 获取订单状态CSS类
function get_status_class($status)
{
    $class_array = [
        1 => 'text-warning',    // 待付款
        2 => 'text-primary',    // 已付款
        3 => 'text-info',       // 待配送
        4 => 'status-active',   // 已完成
        5 => 'status-inactive', // 已取消
        6 => 'text-warning',    // 退款中
        7 => 'status-inactive'  // 已退款
    ];
    return isset($class_array[$status]) ? $class_array[$status] : '';
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单状态管理 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单状态管理</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> / 订单状态管理
            </div>
        </div>

        <div class="content">
            <?php echo $alert; ?>

            <?php if ($action == 'list'): ?>
                <!-- 订单状态统计 -->

                <h3>订单状态统计</h3>
                <div class="dashboard">
                    <?php
                    $all_statuses = [1 => '待付款', 2 => '已付款', 3 => '待配送', 4 => '已完成', 5 => '已取消', 6 => '退款中', 7 => '已退款'];
                    foreach ($all_statuses as $status_id => $status_name):
                    ?>
                        <div class="dashboard-card">
                            <h3><?php echo $status_name; ?></h3>
                            <div class="number"><?php echo isset($status_counts[$status_id]) ? $status_counts[$status_id] : 0; ?></div>
                            <div class="desc">
                                <a href="list.php?status=<?php echo $status_id; ?>">查看详情</a>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>

                <!-- 最近状态变更订单 -->
                <h3>最近状态变更订单</h3>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>订单编号</th>
                                <th>会员</th>
                                <th>订单金额</th>
                                <th>状态</th>
                                <th>更新时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($recent_orders) > 0): ?>
                                <?php foreach ($recent_orders as $order): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                        <td><?php echo empty($order['member_name']) ? '非会员' : htmlspecialchars($order['member_name']); ?></td>
                                        <td>￥<?php echo number_format($order['actual_amount'], 2); ?></td>
                                        <td class="<?php echo get_status_class($order['status']); ?>">
                                            <?php echo get_status_text($order['status']); ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($order['update_time'])); ?></td>
                                        <td>
                                            <a href="list.php?action=view&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                            <?php if (has_permission('order.edit') && in_array($order['status'], [1, 2, 3, 6])): ?>
                                                <a href="status.php?action=edit&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-primary">修改状态</a>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无订单数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php elseif ($action == 'edit' && isset($order)): ?>
                <!-- 编辑订单状态 -->
                <div class="action-bar">
                    <a href="status.php" class="btn btn-secondary">返回状态列表</a>
                    <a href="list.php?action=view&id=<?php echo $order['id']; ?>" class="btn btn-primary">查看订单详情</a>
                </div>

                <h3>修改订单状态</h3>

                <!-- 订单基本信息 -->
                <div class="form-container">
                    <h4>订单信息</h4>
                    <table class="data-table">
                        <tr>
                            <th width="15%">订单编号</th>
                            <td width="35%"><?php echo htmlspecialchars($order['order_no']); ?></td>
                            <th width="15%">当前状态</th>
                            <td width="35%" class="<?php echo get_status_class($order['status']); ?>">
                                <?php echo get_status_text($order['status']); ?>
                            </td>
                        </tr>
                        <tr>
                            <th>会员</th>
                            <td><?php echo empty($order['member_name']) ? '非会员' : htmlspecialchars($order['member_name']); ?></td>
                            <th>门店</th>
                            <td><?php echo htmlspecialchars($order['store_name']); ?></td>
                        </tr>
                        <tr>
                            <th>订单金额</th>
                            <td>￥<?php echo number_format($order['total_amount'], 2); ?></td>
                            <th>实付金额</th>
                            <td>￥<?php echo number_format($order['actual_amount'], 2); ?></td>
                        </tr>
                        <tr>
                            <th>下单时间</th>
                            <td><?php echo date('Y-m-d H:i:s', strtotime($order['create_time'])); ?></td>
                            <th>最后更新</th>
                            <td><?php echo date('Y-m-d H:i:s', strtotime($order['update_time'])); ?></td>
                        </tr>
                    </table>
                </div>

                <!-- 修改状态表单 -->
                <div class="form-container">
                    <h4>更新状态</h4>
                    <form method="post" action="status.php">
                        <input type="hidden" name="action" value="update">
                        <input type="hidden" name="id" value="<?php echo $order['id']; ?>">

                        <div class="form-group">
                            <label for="status">新状态</label>
                            <select id="status" name="status" class="form-control" required>
                                <option value="">请选择</option>
                                <?php
                                // 根据当前状态，显示可选的新状态
                                $valid_transitions = [
                                    1 => [2 => '已付款', 5 => '已取消'],
                                    2 => [3 => '待配送', 6 => '退款中'],
                                    3 => [4 => '已完成', 6 => '退款中'],
                                    6 => [2 => '已付款(取消退款)', 7 => '已退款']
                                ];

                                if (isset($valid_transitions[$order['status']])) {
                                    foreach ($valid_transitions[$order['status']] as $status_id => $status_name) {
                                        echo '<option value="' . $status_id . '">' . $status_name . '</option>';
                                    }
                                }
                                ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注</label>
                            <textarea id="remark" name="remark" class="form-control" rows="3"><?php echo isset($remark) ? htmlspecialchars($remark) : ''; ?></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="status.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>

                <!-- 状态变更说明 -->
                <div class="info-box">
                    <h3>状态变更说明</h3>
                    <ul>
                        <li><strong>待付款 → 已付款</strong>：表示订单已完成支付</li>
                        <li><strong>待付款 → 已取消</strong>：表示订单被取消，不再需要支付</li>
                        <li><strong>已付款 → 待配送</strong>：表示订单已准备完毕，等待配送</li>
                        <li><strong>已付款 → 退款中</strong>：表示客户申请退款，正在处理</li>
                        <li><strong>待配送 → 已完成</strong>：表示订单已送达客户，完成交易</li>
                        <li><strong>待配送 → 退款中</strong>：表示配送过程中客户申请退款</li>
                        <li><strong>退款中 → 已付款</strong>：表示取消退款申请，恢复订单</li>
                        <li><strong>退款中 → 已退款</strong>：表示退款已处理完成</li>
                    </ul>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>