<?php
// product/list.php - 商品管理页面
session_start();
require_once '../database_config.php';

// 检查用户是否有访问权限
check_permission_or_die('product');

// 处理商品添加/修改/删除操作
$message = '';
$message_type = '';

// 处理添加/修改商品
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] == 'add' || $_POST['action'] == 'edit') {
        // 验证输入
        $required_fields = ['category_id', 'name', 'code', 'price', 'warning_stock'];
        $missing_fields = [];

        foreach ($required_fields as $field) {
            if (empty($_POST[$field])) {
                $missing_fields[] = $field;
            }
        }

        if (!empty($missing_fields)) {
            $message = '请填写所有必填字段: ' . implode(', ', $missing_fields);
            $message_type = 'danger';
        } else {
            // 准备数据
            $data = [
                'category_id' => $_POST['category_id'],
                'name' => $_POST['name'],
                'code' => $_POST['code'],
                'price' => $_POST['price'],
                'cost_price' => !empty($_POST['cost_price']) ? $_POST['cost_price'] : null,
                'spec' => $_POST['spec'],
                'description' => $_POST['description'],
                'warning_stock' => $_POST['warning_stock'],
                'status' => isset($_POST['status']) ? 1 : 0
            ];

            try {
                // 添加或修改商品
                if ($_POST['action'] == 'add') {
                    // 初始库存为0
                    $data['stock'] = 0;

                    // 检查商品编码是否已存在
                    $stmt = $pdo->prepare("SELECT id FROM products WHERE code = ?");
                    $stmt->execute([$data['code']]);
                    if ($stmt->rowCount() > 0) {
                        $message = '商品编码已存在，请使用其他编码';
                        $message_type = 'danger';
                    } else {
                        // 插入新商品
                        $columns = implode(', ', array_keys($data));
                        $placeholders = implode(', ', array_fill(0, count($data), '?'));

                        $stmt = $pdo->prepare("INSERT INTO products ($columns) VALUES ($placeholders)");
                        $stmt->execute(array_values($data));

                        $product_id = $pdo->lastInsertId();
                        $message = '商品添加成功！';
                        $message_type = 'success';

                        // 记录操作日志
                        record_log("添加商品: {$data['name']} (ID: $product_id)");
                    }
                } else { // 修改商品
                    $product_id = $_POST['product_id'];

                    // 检查商品编码是否与其他商品重复
                    $stmt = $pdo->prepare("SELECT id FROM products WHERE code = ? AND id != ?");
                    $stmt->execute([$data['code'], $product_id]);
                    if ($stmt->rowCount() > 0) {
                        $message = '商品编码已被其他商品使用，请更换';
                        $message_type = 'danger';
                    } else {
                        // 更新商品信息
                        $set_clauses = [];
                        foreach ($data as $key => $value) {
                            $set_clauses[] = "$key = ?";
                        }
                        $set_clause = implode(', ', $set_clauses);

                        $values = array_values($data);
                        $values[] = $product_id; // WHERE条件的值

                        $stmt = $pdo->prepare("UPDATE products SET $set_clause WHERE id = ?");
                        $stmt->execute($values);

                        $message = '商品信息更新成功！';
                        $message_type = 'success';

                        // 记录操作日志
                        record_log("更新商品: {$data['name']} (ID: $product_id)");
                    }
                }
            } catch (PDOException $e) {
                $message = '操作失败: ' . $e->getMessage();
                $message_type = 'danger';
            }
        }
    } elseif ($_POST['action'] == 'delete' && isset($_POST['product_id'])) {
        $product_id = $_POST['product_id'];

        // 检查该商品是否有库存记录
        $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM inventory_records WHERE product_id = ?");
        $stmt->execute([$product_id]);
        $inventory_count = $stmt->fetch()['count'];

        if ($inventory_count > 0) {
            $message = '该商品有库存记录，无法删除。您可以将其状态设置为下架。';
            $message_type = 'danger';
        } else {
            try {
                // 获取商品名称用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM products WHERE id = ?");
                $stmt->execute([$product_id]);
                $product_name = $stmt->fetch()['name'];

                // 删除商品
                $stmt = $pdo->prepare("DELETE FROM products WHERE id = ?");
                $stmt->execute([$product_id]);

                $message = '商品删除成功！';
                $message_type = 'success';

                // 记录操作日志
                record_log("删除商品: $product_name (ID: $product_id)");
            } catch (PDOException $e) {
                $message = '删除失败: ' . $e->getMessage();
                $message_type = 'danger';
            }
        }
    } elseif ($_POST['action'] == 'status' && isset($_POST['product_id']) && isset($_POST['status'])) {
        $product_id = $_POST['product_id'];
        $status = $_POST['status'];

        try {
            // 更新商品状态
            $stmt = $pdo->prepare("UPDATE products SET status = ? WHERE id = ?");
            $stmt->execute([$status, $product_id]);

            // 获取商品名称用于日志记录
            $stmt = $pdo->prepare("SELECT name FROM products WHERE id = ?");
            $stmt->execute([$product_id]);
            $product_name = $stmt->fetch()['name'];

            $status_text = $status ? '上架' : '下架';
            $message = "商品已{$status_text}！";
            $message_type = 'success';

            // 记录操作日志
            record_log("修改商品状态: $product_name (ID: $product_id) - {$status_text}");
        } catch (PDOException $e) {
            $message = '操作失败: ' . $e->getMessage();
            $message_type = 'danger';
        }
    }
}

// 准备查询条件
$where_conditions = [];
$params = [];

// 过滤条件
$filter_category = isset($_GET['category']) ? $_GET['category'] : '';
if (!empty($filter_category)) {
    $where_conditions[] = "p.category_id = ?";
    $params[] = $filter_category;
}

$filter_status = isset($_GET['status']) ? $_GET['status'] : '';
if ($filter_status !== '') {
    $where_conditions[] = "p.status = ?";
    $params[] = $filter_status;
}

$filter_keyword = isset($_GET['keyword']) ? $_GET['keyword'] : '';
if (!empty($filter_keyword)) {
    $where_conditions[] = "(p.name LIKE ? OR p.code LIKE ? OR p.description LIKE ?)";
    $params[] = "%$filter_keyword%";
    $params[] = "%$filter_keyword%";
    $params[] = "%$filter_keyword%";
}

// 库存预警筛选
if (isset($_GET['filter']) && $_GET['filter'] == 'warning') {
    $where_conditions[] = "p.stock <= p.warning_stock";
}

// 构建WHERE子句
$where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

// 分页
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;

// 获取总记录数
$count_sql = "SELECT COUNT(*) as total FROM products p $where_clause";
$stmt = $pdo->prepare($count_sql);
$stmt->execute($params);
$total_records = $stmt->fetch()['total'];
$total_pages = ceil($total_records / $limit);

// 获取分页数据
$sql = "SELECT p.*, c.name as category_name 
        FROM products p 
        LEFT JOIN product_categories c ON p.category_id = c.id 
        $where_clause 
        ORDER BY p.id DESC 
        LIMIT $offset, $limit";

$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$products = $stmt->fetchAll();

// 获取商品分类列表
$stmt = $pdo->query("SELECT id, name FROM product_categories ORDER BY id");
$categories = $stmt->fetchAll();

// 记录操作日志
record_log("查看商品列表");
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>商品管理 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>商品管理</h2>
            <div class="breadcrumb">
                <a href="index.php">商品与库存管理</a> &gt;
                商品管理
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $message_type; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <!-- 添加商品按钮 -->
            <div class="action-bar">
                <button class="btn btn-primary" onclick="toggleForm('addProductForm')">添加新商品</button>
            </div>

            <!-- 添加商品表单 -->
            <div id="addProductForm" class="form-container" style="display: none;">
                <h3>添加新商品</h3>
                <form method="post" action="list.php">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="category_id">商品分类 <span class="text-danger">*</span></label>
                        <select name="category_id" id="category_id" required>
                            <option value="">请选择分类</option>
                            <?php foreach ($categories as $category): ?>
                                <option value="<?php echo $category['id']; ?>">
                                    <?php echo htmlspecialchars($category['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="name">商品名称 <span class="text-danger">*</span></label>
                        <input type="text" id="name" name="name" required>
                    </div>

                    <div class="form-group">
                        <label for="code">商品编码 <span class="text-danger">*</span></label>
                        <input type="text" id="code" name="code" required>
                    </div>

                    <div class="form-group">
                        <label for="price">销售价格 <span class="text-danger">*</span></label>
                        <input type="number" id="price" name="price" step="0.01" min="0" required>
                    </div>

                    <div class="form-group">
                        <label for="cost_price">成本价格</label>
                        <input type="number" id="cost_price" name="cost_price" step="0.01" min="0">
                    </div>

                    <div class="form-group">
                        <label for="spec">规格</label>
                        <input type="text" id="spec" name="spec">
                    </div>

                    <div class="form-group">
                        <label for="description">商品描述</label>
                        <input type="text" id="description" name="description">
                    </div>

                    <div class="form-group">
                        <label for="warning_stock">库存预警阈值 <span class="text-danger">*</span></label>
                        <input type="number" id="warning_stock" name="warning_stock" min="0" value="5" required>
                    </div>

                    <div class="form-group">
                        <label for="status">
                            <input type="checkbox" id="status" name="status" checked>
                            商品状态（勾选为上架，不勾选为下架）
                        </label>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="toggleForm('addProductForm')">取消</button>
                    </div>
                </form>
            </div>

            <!-- 编辑商品表单 -->
            <div id="editProductForm" class="form-container" style="display: none;">
                <h3>编辑商品</h3>
                <form method="post" action="list.php">
                    <input type="hidden" name="action" value="edit">
                    <input type="hidden" name="product_id" id="edit_product_id">

                    <div class="form-group">
                        <label for="edit_category_id">商品分类 <span class="text-danger">*</span></label>
                        <select name="category_id" id="edit_category_id" required>
                            <option value="">请选择分类</option>
                            <?php foreach ($categories as $category): ?>
                                <option value="<?php echo $category['id']; ?>">
                                    <?php echo htmlspecialchars($category['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="edit_name">商品名称 <span class="text-danger">*</span></label>
                        <input type="text" id="edit_name" name="name" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_code">商品编码 <span class="text-danger">*</span></label>
                        <input type="text" id="edit_code" name="code" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_price">销售价格 <span class="text-danger">*</span></label>
                        <input type="number" id="edit_price" name="price" step="0.01" min="0" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_cost_price">成本价格</label>
                        <input type="number" id="edit_cost_price" name="cost_price" step="0.01" min="0">
                    </div>

                    <div class="form-group">
                        <label for="edit_spec">规格</label>
                        <input type="text" id="edit_spec" name="spec">
                    </div>

                    <div class="form-group">
                        <label for="edit_description">商品描述</label>
                        <input type="text" id="edit_description" name="description">
                    </div>

                    <div class="form-group">
                        <label for="edit_warning_stock">库存预警阈值 <span class="text-danger">*</span></label>
                        <input type="number" id="edit_warning_stock" name="warning_stock" min="0" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_status">
                            <input type="checkbox" id="edit_status" name="status">
                            商品状态（勾选为上架，不勾选为下架）
                        </label>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="toggleForm('editProductForm')">取消</button>
                    </div>
                </form>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="list.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="category">商品分类</label>
                            <select name="category" id="category">
                                <option value="">所有分类</option>
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category['id']; ?>" <?php echo $filter_category == $category['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($category['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="status">商品状态</label>
                            <select name="status" id="status">
                                <option value="">所有状态</option>
                                <option value="1" <?php echo $filter_status === '1' ? 'selected' : ''; ?>>上架</option>
                                <option value="0" <?php echo $filter_status === '0' ? 'selected' : ''; ?>>下架</option>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="keyword">关键字搜索</label>
                            <input type="text" id="keyword" name="keyword" placeholder="商品名称/编码/描述" value="<?php echo htmlspecialchars($filter_keyword); ?>">
                        </div>
                        <div class="filter-item">
                            <label>&nbsp;</label>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="list.php" class="btn btn-secondary">重置</a>
                                <?php if (empty($_GET['filter']) || $_GET['filter'] != 'warning'): ?>
                                    <a href="list.php?filter=warning" class="btn btn-danger">查看库存预警</a>
                                <?php else: ?>
                                    <a href="list.php" class="btn btn-secondary">取消筛选预警</a>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 商品表格 -->
            <div class="table-responsive">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>商品编码</th>
                            <th>商品名称</th>
                            <th>分类</th>
                            <th>销售价格</th>
                            <th>成本价格</th>
                            <th>库存</th>
                            <th>预警库存</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($products as $product): ?>
                            <tr>
                                <td><?php echo $product['id']; ?></td>
                                <td><?php echo htmlspecialchars($product['code']); ?></td>
                                <td><?php echo htmlspecialchars($product['name']); ?></td>
                                <td><?php echo htmlspecialchars($product['category_name']); ?></td>
                                <td>￥<?php echo number_format($product['price'], 2); ?></td>
                                <td><?php echo $product['cost_price'] ? '￥' . number_format($product['cost_price'], 2) : '-'; ?></td>
                                <td class="<?php echo $product['stock'] <= $product['warning_stock'] ? 'status-inactive' : ''; ?>">
                                    <?php echo $product['stock']; ?>
                                </td>
                                <td><?php echo $product['warning_stock']; ?></td>
                                <td class="<?php echo $product['status'] ? 'status-active' : 'status-inactive'; ?>">
                                    <?php echo $product['status'] ? '上架' : '下架'; ?>
                                </td>
                                <td>
                                    <button class="btn btn-sm btn-primary" onclick="showEditForm(<?php echo htmlspecialchars(json_encode($product)); ?>)">编辑</button>

                                    <?php if ($product['status']): ?>
                                        <form method="post" action="list.php" style="display:inline;">
                                            <input type="hidden" name="action" value="status">
                                            <input type="hidden" name="product_id" value="<?php echo $product['id']; ?>">
                                            <input type="hidden" name="status" value="0">
                                            <button type="submit" class="btn btn-sm btn-secondary" onclick="return confirm('确定要下架此商品吗？')">下架</button>
                                        </form>
                                    <?php else: ?>
                                        <form method="post" action="list.php" style="display:inline;">
                                            <input type="hidden" name="action" value="status">
                                            <input type="hidden" name="product_id" value="<?php echo $product['id']; ?>">
                                            <input type="hidden" name="status" value="1">
                                            <button type="submit" class="btn btn-sm btn-success">上架</button>
                                        </form>
                                    <?php endif; ?>

                                    <form method="post" action="list.php" style="display:inline;">
                                        <input type="hidden" name="action" value="delete">
                                        <input type="hidden" name="product_id" value="<?php echo $product['id']; ?>">
                                        <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此商品吗？删除后无法恢复！')">删除</button>
                                    </form>
                                </td>
                            </tr>
                        <?php endforeach; ?>

                        <?php if (empty($products)): ?>
                            <tr>
                                <td colspan="10" class="text-center">没有找到符合条件的商品</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页 -->
            <?php if ($total_pages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?page=1<?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">首页</a>
                        <a href="?page=<?php echo $page - 1; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">上一页</a>
                    <?php endif; ?>

                    <?php
                    $start_page = max(1, $page - 2);
                    $end_page = min($total_pages, $page + 2);

                    for ($i = $start_page; $i <= $end_page; $i++):
                    ?>
                        <a href="?page=<?php echo $i; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>">
                            <?php echo $i; ?>
                        </a>
                    <?php endfor; ?>

                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?php echo $page + 1; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">下一页</a>
                        <a href="?page=<?php echo $total_pages; ?><?php echo !empty($_GET) ? '&' . http_build_query(array_diff_key($_GET, ['page' => ''])) : ''; ?>" class="page-link">末页</a>
                    <?php endif; ?>
                </div>
                <div class="pagination-info">
                    共 <?php echo $total_records; ?> 条记录，当前第 <?php echo $page; ?>/<?php echo $total_pages; ?> 页
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 切换表单显示/隐藏
        function toggleForm(formId) {
            const form = document.getElementById(formId);
            if (form.style.display === 'none' || form.style.display === '') {
                form.style.display = 'block';
            } else {
                form.style.display = 'none';
            }
        }

        // 显示添加商品表单
        function showAddForm() {
            document.getElementById('editProductForm').style.display = 'none'; // 隐藏编辑表单
            toggleForm('addProductForm');
        }

        // 显示编辑商品表单并填充数据
        function showEditForm(product) {
            // 填充表单字段
            document.getElementById('edit_product_id').value = product.id;
            document.getElementById('edit_category_id').value = product.category_id;
            document.getElementById('edit_name').value = product.name;
            document.getElementById('edit_code').value = product.code;
            document.getElementById('edit_price').value = product.price;
            document.getElementById('edit_cost_price').value = product.cost_price || '';
            document.getElementById('edit_spec').value = product.spec || '';
            document.getElementById('edit_description').value = product.description || '';
            document.getElementById('edit_warning_stock').value = product.warning_stock;
            document.getElementById('edit_status').checked = product.status == 1;

            // 隐藏添加表单，显示编辑表单
            document.getElementById('addProductForm').style.display = 'none';
            document.getElementById('editProductForm').style.display = 'block';
        }

        // 隐藏编辑商品表单
        function hideEditForm() {
            document.getElementById('editProductForm').style.display = 'none';
        }

        // 隐藏添加商品表单
        function hideAddForm() {
            document.getElementById('addProductForm').style.display = 'none';
        }
    </script>
</body>

</html>