<?php
// statistics/member.php - 会员数据统计页面
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('statistics.view');

// 记录访问日志
record_log('访问会员数据统计页面');

// 处理日期筛选
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$custom_start = isset($_GET['custom_start']) ? $_GET['custom_start'] : '';
$custom_end = isset($_GET['custom_end']) ? $_GET['custom_end'] : '';

// 根据选择的日期范围确定开始和结束日期
$start_date = '';
$end_date = date('Y-m-d');

switch ($date_range) {
    case 'today':
        $start_date = date('Y-m-d');
        break;
    case 'yesterday':
        $start_date = date('Y-m-d', strtotime('-1 day'));
        $end_date = date('Y-m-d', strtotime('-1 day'));
        break;
    case 'week':
        $start_date = date('Y-m-d', strtotime('-7 days'));
        break;
    case 'month':
        $start_date = date('Y-m-d', strtotime('-30 days'));
        break;
    case 'quarter':
        $start_date = date('Y-m-d', strtotime('-90 days'));
        break;
    case 'year':
        $start_date = date('Y-m-d', strtotime('-365 days'));
        break;
    case 'custom':
        if (!empty($custom_start)) {
            $start_date = $custom_start;
        } else {
            $start_date = date('Y-m-d', strtotime('-30 days'));
        }

        if (!empty($custom_end)) {
            $end_date = $custom_end;
        }
        break;
    default:
        $start_date = date('Y-m-d', strtotime('-30 days'));
}

// 获取会员总数据概览
$member_overview = [
    'total' => 0,
    'active' => 0,
    'new' => 0,
    'active_rate' => 0
];

try {
    // 获取会员总数
    $stmt = $pdo->query("SELECT COUNT(*) as total FROM members");
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($result) {
        $member_overview['total'] = $result['total'];
    }

    // 获取活跃会员数（在选定时间范围内有订单的会员）
    $stmt = $pdo->prepare("
        SELECT COUNT(DISTINCT member_id) as active
        FROM orders
        WHERE member_id IS NOT NULL
        AND create_time BETWEEN ? AND ?
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($result) {
        $member_overview['active'] = $result['active'];
        if ($member_overview['total'] > 0) {
            $member_overview['active_rate'] = round(($member_overview['active'] / $member_overview['total']) * 100, 1);
        }
    }

    // 获取新增会员数
    $stmt = $pdo->prepare("
        SELECT COUNT(*) as new
        FROM members
        WHERE create_time BETWEEN ? AND ?
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($result) {
        $member_overview['new'] = $result['new'];
    }
} catch (PDOException $e) {
    $error_message = '获取会员概览数据失败: ' . $e->getMessage();
}

// 会员等级分布
$member_levels = [];

try {
    $stmt = $pdo->query("
        SELECT 
            ml.id,
            ml.level_name,
            COUNT(m.id) as member_count,
            ROUND(COUNT(m.id) * 100 / (SELECT COUNT(*) FROM members), 1) as percentage
        FROM member_levels ml
        LEFT JOIN members m ON ml.id = m.level_id
        GROUP BY ml.id, ml.level_name
        ORDER BY ml.id
    ");
    $member_levels = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取会员等级分布数据失败: ' . $e->getMessage();
}

// 会员增长趋势
$member_growth = [];
$period_type = isset($_GET['period_type']) ? $_GET['period_type'] : 'day';

try {
    $sql_format = '';
    switch ($period_type) {
        case 'day':
            $sql_format = '%Y-%m-%d';
            break;
        case 'week':
            $sql_format = '%Y-%u';
            break;
        case 'month':
            $sql_format = '%Y-%m';
            break;
    }

    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(create_time, ?) as period,
            COUNT(*) as new_members
        FROM members
        WHERE create_time BETWEEN ? AND ?
        GROUP BY period
        ORDER BY MIN(create_time)
    ");
    $stmt->execute([$sql_format, $start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $member_growth = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取会员增长趋势数据失败: ' . $e->getMessage();
}

// 消费频率分析
$purchase_frequency = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            m.id,
            m.name,
            COUNT(o.id) as order_count,
            SUM(o.total_amount) as total_amount,
            AVG(o.total_amount) as avg_amount,
            MAX(o.create_time) as last_order_time
        FROM members m
        JOIN orders o ON m.id = o.member_id
        WHERE o.create_time BETWEEN ? AND ?
        GROUP BY m.id, m.name
        ORDER BY order_count DESC
        LIMIT 10
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $purchase_frequency = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取消费频率数据失败: ' . $e->getMessage();
}

// 会员消费金额分布
$purchase_amount_distribution = [
    '0-100' => 0,
    '100-500' => 0,
    '500-1000' => 0,
    '1000-5000' => 0,
    '5000+' => 0
];

try {
    $stmt = $pdo->prepare("
        SELECT 
            m.id,
            SUM(o.total_amount) as total_amount
        FROM members m
        JOIN orders o ON m.id = o.member_id
        WHERE o.create_time BETWEEN ? AND ?
        GROUP BY m.id
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);

    while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $amount = floatval($row['total_amount']);

        if ($amount <= 100) {
            $purchase_amount_distribution['0-100']++;
        } elseif ($amount <= 500) {
            $purchase_amount_distribution['100-500']++;
        } elseif ($amount <= 1000) {
            $purchase_amount_distribution['500-1000']++;
        } elseif ($amount <= 5000) {
            $purchase_amount_distribution['1000-5000']++;
        } else {
            $purchase_amount_distribution['5000+']++;
        }
    }
} catch (PDOException $e) {
    $error_message = '获取会员消费金额分布数据失败: ' . $e->getMessage();
}

// 会员商品类别偏好
$product_category_preferences = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            pc.id,
            pc.name as category_name,
            COUNT(DISTINCT o.member_id) as member_count
        FROM orders o
        JOIN order_items oi ON o.id = oi.order_id
        JOIN products p ON oi.product_id = p.id
        JOIN product_categories pc ON p.category_id = pc.id
        WHERE o.create_time BETWEEN ? AND ?
        AND o.member_id IS NOT NULL
        GROUP BY pc.id, pc.name
        ORDER BY member_count DESC
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $product_category_preferences = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取会员商品类别偏好数据失败: ' . $e->getMessage();
}

// 准备会员增长趋势图表数据
$growth_periods = [];
$growth_counts = [];

foreach ($member_growth as $item) {
    $growth_periods[] = $item['period'];
    $growth_counts[] = $item['new_members'];
}

$growth_periods_json = json_encode($growth_periods);
$growth_counts_json = json_encode($growth_counts);

// 准备会员等级分布图表数据
$level_names = [];
$level_counts = [];

foreach ($member_levels as $level) {
    $level_names[] = $level['level_name'];
    $level_counts[] = $level['member_count'];
}

$level_names_json = json_encode($level_names);
$level_counts_json = json_encode($level_counts);

// 准备消费金额分布图表数据
$amount_ranges = array_keys($purchase_amount_distribution);
$amount_counts = array_values($purchase_amount_distribution);

$amount_ranges_json = json_encode($amount_ranges);
$amount_counts_json = json_encode($amount_counts);
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员数据分析 - FloraEase花店管理系统</title>
    <link rel="stylesheet" href="../style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员数据分析</h2>
            <div class="breadcrumb">
                <a href="index.php">数据统计与分析</a> / 会员数据
            </div>
        </div>

        <div class="content">
            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger">
                    <?php echo $error_message; ?>
                </div>
            <?php endif; ?>

            <!-- 日期筛选 -->
            <div class="filter-form">
                <form method="get" action="member.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="date_range">时间范围</label>
                            <select id="date_range" name="date_range" onchange="toggleCustomDateFields()">
                                <option value="today" <?php echo $date_range == 'today' ? 'selected' : ''; ?>>今日</option>
                                <option value="yesterday" <?php echo $date_range == 'yesterday' ? 'selected' : ''; ?>>昨日</option>
                                <option value="week" <?php echo $date_range == 'week' ? 'selected' : ''; ?>>近7天</option>
                                <option value="month" <?php echo $date_range == 'month' ? 'selected' : ''; ?>>近30天</option>
                                <option value="quarter" <?php echo $date_range == 'quarter' ? 'selected' : ''; ?>>近90天</option>
                                <option value="year" <?php echo $date_range == 'year' ? 'selected' : ''; ?>>近一年</option>
                                <option value="custom" <?php echo $date_range == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="filter-item custom-date" style="display: <?php echo $date_range == 'custom' ? 'block' : 'none'; ?>;">
                            <label for="custom_start">开始日期</label>
                            <input type="date" id="custom_start" name="custom_start" value="<?php echo $custom_start; ?>">
                        </div>
                        <div class="filter-item custom-date" style="display: <?php echo $date_range == 'custom' ? 'block' : 'none'; ?>;">
                            <label for="custom_end">结束日期</label>
                            <input type="date" id="custom_end" name="custom_end" value="<?php echo $custom_end; ?>">
                        </div>
                        <div class="filter-item">
                            <label for="period_type">趋势周期</label>
                            <select id="period_type" name="period_type">
                                <option value="day" <?php echo $period_type == 'day' ? 'selected' : ''; ?>>按日</option>
                                <option value="week" <?php echo $period_type == 'week' ? 'selected' : ''; ?>>按周</option>
                                <option value="month" <?php echo $period_type == 'month' ? 'selected' : ''; ?>>按月</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">查询</button>
                        <a href="member.php" class="btn btn-secondary">重置</a>
                    </div>
                </form>
            </div>

            <!-- 会员概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>会员总数</h3>
                    <div class="number"><?php echo number_format($member_overview['total']); ?></div>
                    <div class="desc">新增会员: <?php echo number_format($member_overview['new']); ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>活跃会员</h3>
                    <div class="number"><?php echo number_format($member_overview['active']); ?></div>
                    <div class="desc">活跃率: <?php echo $member_overview['active_rate']; ?>%</div>
                </div>
                <div class="dashboard-card">
                    <h3>时段</h3>
                    <div class="number"><?php echo $start_date; ?></div>
                    <div class="desc">至 <?php echo $end_date; ?></div>
                </div>
            </div>

            <!-- 会员增长趋势 -->
            <div class="section">
                <h2>会员增长趋势</h2>
                <div class="chart-container" style="position: relative; height:300px;">
                    <canvas id="memberGrowthChart"></canvas>
                </div>
            </div>

            <!-- 会员等级分布 -->
            <div class="section">
                <h2>会员等级分布</h2>
                <div class="row">
                    <div class="chart-container" style="position: relative; height:300px; width:50%; float:left;">
                        <canvas id="memberLevelChart"></canvas>
                    </div>
                    <div class="table-container" style="width:50%; float:left;">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>会员等级</th>
                                    <th>会员数量</th>
                                    <th>占比</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (!empty($member_levels)): ?>
                                    <?php foreach ($member_levels as $level): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($level['level_name']); ?></td>
                                            <td><?php echo number_format($level['member_count']); ?></td>
                                            <td><?php echo $level['percentage']; ?>%</td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="3" class="text-center">暂无数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                    <div style="clear:both;"></div>
                </div>
            </div>

            <!-- 会员活跃度 - 消费频率 -->
            <div class="section">
                <h2>消费频率分析（活跃度）</h2>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>会员姓名</th>
                                <th>订单数量</th>
                                <th>消费总额</th>
                                <th>平均单价</th>
                                <th>最近消费时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($purchase_frequency)): ?>
                                <?php foreach ($purchase_frequency as $member): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($member['name']); ?></td>
                                        <td><?php echo $member['order_count']; ?></td>
                                        <td>￥<?php echo number_format($member['total_amount'], 2); ?></td>
                                        <td>￥<?php echo number_format($member['avg_amount'], 2); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($member['last_order_time'])); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <!-- 消费金额分布 -->
            <div class="section">
                <h2>消费金额分布</h2>
                <div class="row">
                    <div class="chart-container" style="position: relative; height:300px; width:50%; float:left;">
                        <canvas id="purchaseAmountChart"></canvas>
                    </div>
                    <div class="table-container" style="width:50%; float:left;">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>消费金额区间</th>
                                    <th>会员数量</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (array_sum($purchase_amount_distribution) > 0): ?>
                                    <?php foreach ($purchase_amount_distribution as $range => $count): ?>
                                        <tr>
                                            <td><?php echo $range; ?></td>
                                            <td><?php echo number_format($count); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="2" class="text-center">暂无数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                    <div style="clear:both;"></div>
                </div>
            </div>

            <!-- 商品类别偏好 -->
            <div class="section">
                <h2>商品类别偏好</h2>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>商品类别</th>
                                <th>消费会员数</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($product_category_preferences)): ?>
                                <?php foreach ($product_category_preferences as $category): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($category['category_name']); ?></td>
                                        <td><?php echo number_format($category['member_count']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="2" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    <script>
        // 控制自定义日期字段的显示与隐藏
        function toggleCustomDateFields() {
            var dateRange = document.getElementById('date_range').value;
            var customDateFields = document.querySelectorAll('.custom-date');

            for (var i = 0; i < customDateFields.length; i++) {
                customDateFields[i].style.display = dateRange === 'custom' ? 'block' : 'none';
            }
        }

        // 绘制会员增长趋势图
        var ctx1 = document.getElementById('memberGrowthChart').getContext('2d');
        var memberGrowthChart = new Chart(ctx1, {
            type: 'line',
            data: {
                labels: <?php echo $growth_periods_json; ?>,
                datasets: [{
                    label: '新增会员数',
                    data: <?php echo $growth_counts_json; ?>,
                    backgroundColor: 'rgba(54, 162, 235, 0.2)',
                    borderColor: 'rgba(54, 162, 235, 1)',
                    borderWidth: 1,
                    tension: 0.4
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '人数'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '时间'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '会员增长趋势'
                    }
                }
            }
        });

        // 绘制会员等级分布图
        var ctx2 = document.getElementById('memberLevelChart').getContext('2d');
        var memberLevelChart = new Chart(ctx2, {
            type: 'pie',
            data: {
                labels: <?php echo $level_names_json; ?>,
                datasets: [{
                    data: <?php echo $level_counts_json; ?>,
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.7)',
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)',
                        'rgba(75, 192, 192, 0.7)',
                        'rgba(153, 102, 255, 0.7)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        position: 'right'
                    },
                    title: {
                        display: true,
                        text: '会员等级分布'
                    }
                }
            }
        });

        // 绘制消费金额分布图
        var ctx3 = document.getElementById('purchaseAmountChart').getContext('2d');
        var purchaseAmountChart = new Chart(ctx3, {
            type: 'bar',
            data: {
                labels: <?php echo $amount_ranges_json; ?>,
                datasets: [{
                    label: '会员数量',
                    data: <?php echo $amount_counts_json; ?>,
                    backgroundColor: 'rgba(75, 192, 192, 0.7)',
                    borderColor: 'rgba(75, 192, 192, 1)',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '会员数量'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '消费金额区间（元）'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '会员消费金额分布'
                    }
                }
            }
        });
    </script>
</body>

</html>