<?php
// statistics/order.php - 订单数据统计页面
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('statistics.view');

// 记录访问日志
record_log('访问订单数据统计页面');

// 处理日期筛选
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$custom_start = isset($_GET['custom_start']) ? $_GET['custom_start'] : '';
$custom_end = isset($_GET['custom_end']) ? $_GET['custom_end'] : '';

// 根据选择的日期范围确定开始和结束日期
$start_date = '';
$end_date = date('Y-m-d');

switch ($date_range) {
    case 'today':
        $start_date = date('Y-m-d');
        break;
    case 'yesterday':
        $start_date = date('Y-m-d', strtotime('-1 day'));
        $end_date = date('Y-m-d', strtotime('-1 day'));
        break;
    case 'week':
        $start_date = date('Y-m-d', strtotime('-7 days'));
        break;
    case 'month':
        $start_date = date('Y-m-d', strtotime('-30 days'));
        break;
    case 'quarter':
        $start_date = date('Y-m-d', strtotime('-90 days'));
        break;
    case 'year':
        $start_date = date('Y-m-d', strtotime('-365 days'));
        break;
    case 'custom':
        if (!empty($custom_start)) {
            $start_date = $custom_start;
        } else {
            $start_date = date('Y-m-d', strtotime('-30 days'));
        }

        if (!empty($custom_end)) {
            $end_date = $custom_end;
        }
        break;
    default:
        $start_date = date('Y-m-d', strtotime('-30 days'));
}

// 获取订单概览数据
$order_overview = [
    'total' => 0,
    'completed' => 0,
    'refunded' => 0,
    'refund_rate' => 0,
    'avg_amount' => 0
];

try {
    // 获取总订单数
    $stmt = $pdo->prepare("
        SELECT 
            COUNT(*) as total,
            SUM(CASE WHEN status = 4 THEN 1 ELSE 0 END) as completed,
            SUM(CASE WHEN status IN (5, 6) THEN 1 ELSE 0 END) as refunded,
            AVG(total_amount) as avg_amount
        FROM orders
        WHERE create_time BETWEEN ? AND ?
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($result) {
        $order_overview['total'] = $result['total'] ?: 0;
        $order_overview['completed'] = $result['completed'] ?: 0;
        $order_overview['refunded'] = $result['refunded'] ?: 0;
        $order_overview['avg_amount'] = $result['avg_amount'] ?: 0;

        // 计算退款率
        if ($order_overview['total'] > 0) {
            $order_overview['refund_rate'] = round(($order_overview['refunded'] / $order_overview['total']) * 100, 1);
        }
    }
} catch (PDOException $e) {
    $error_message = '获取订单概览数据失败: ' . $e->getMessage();
}

// 订单数量趋势
$order_trend = [];
$period_type = isset($_GET['period_type']) ? $_GET['period_type'] : 'day';

try {
    $sql_format = '';
    switch ($period_type) {
        case 'day':
            $sql_format = '%Y-%m-%d';
            break;
        case 'week':
            $sql_format = '%Y-%u';
            break;
        case 'month':
            $sql_format = '%Y-%m';
            break;
    }

    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(create_time, ?) as period,
            COUNT(*) as order_count,
            SUM(total_amount) as order_amount
        FROM orders
        WHERE create_time BETWEEN ? AND ?
        GROUP BY period
        ORDER BY MIN(create_time)
    ");
    $stmt->execute([$sql_format, $start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $order_trend = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取订单趋势数据失败: ' . $e->getMessage();
}

// 退款率统计（按日期）
$refund_trend = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(o.create_time, ?) as period,
            COUNT(o.id) as total_orders,
            SUM(CASE WHEN o.status IN (5, 6) THEN 1 ELSE 0 END) as refunded_orders,
            COALESCE(
                SUM(CASE WHEN o.status IN (5, 6) THEN 1 ELSE 0 END) / COUNT(o.id) * 100,
                0
            ) as refund_rate
        FROM orders o
        WHERE o.create_time BETWEEN ? AND ?
        GROUP BY period
        ORDER BY MIN(o.create_time)
    ");
    $stmt->execute([$sql_format, $start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $refund_trend = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取退款率趋势数据失败: ' . $e->getMessage();
}

// 退款原因分析
$refund_reasons = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            reason as refund_reason,
            COUNT(*) as count,
            ROUND(COUNT(*) * 100 / (
                SELECT COUNT(*) FROM order_refunds 
                WHERE create_time BETWEEN ? AND ?
            ), 1) as percentage
        FROM order_refunds
        WHERE create_time BETWEEN ? AND ?
        GROUP BY reason
        ORDER BY count DESC
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59', $start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $refund_reasons = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取退款原因数据失败: ' . $e->getMessage();
}

// 订单状态分布
$order_status = [];

try {
    $stmt = $pdo->query("
        SELECT 
            status,
            CASE 
                WHEN status = 0 THEN '待付款'
                WHEN status = 1 THEN '已付款'
                WHEN status = 2 THEN '待配送'
                WHEN status = 3 THEN '配送中'
                WHEN status = 4 THEN '已完成'
                WHEN status = 5 THEN '退款中'
                WHEN status = 6 THEN '已退款'
                WHEN status = 7 THEN '已取消'
                ELSE '未知状态'
            END as status_name,
            COUNT(*) as count,
            ROUND(COUNT(*) * 100 / (SELECT COUNT(*) FROM orders), 1) as percentage
        FROM orders
        GROUP BY status, status_name
        ORDER BY status
    ");
    $order_status = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取订单状态分布数据失败: ' . $e->getMessage();
}

// 配送时间分析
$delivery_time = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            TIMESTAMPDIFF(HOUR, o.create_time, dt.update_time) as hours,
            COUNT(*) as count
        FROM orders o
        JOIN delivery_tasks dt ON o.id = dt.order_id
        WHERE o.create_time BETWEEN ? AND ?
        AND dt.status = 3 -- 已送达
        GROUP BY hours
        ORDER BY hours
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $delivery_time_raw = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 将配送时间按区间分组
    $time_ranges = [
        '1小时内' => 0,
        '1-2小时' => 0,
        '2-4小时' => 0,
        '4-8小时' => 0,
        '8-24小时' => 0,
        '24小时以上' => 0
    ];

    foreach ($delivery_time_raw as $item) {
        $hours = intval($item['hours']);
        $count = intval($item['count']);

        if ($hours < 1) {
            $time_ranges['1小时内'] += $count;
        } elseif ($hours < 2) {
            $time_ranges['1-2小时'] += $count;
        } elseif ($hours < 4) {
            $time_ranges['2-4小时'] += $count;
        } elseif ($hours < 8) {
            $time_ranges['4-8小时'] += $count;
        } elseif ($hours < 24) {
            $time_ranges['8-24小时'] += $count;
        } else {
            $time_ranges['24小时以上'] += $count;
        }
    }

    // 转换为图表数据格式
    foreach ($time_ranges as $range => $count) {
        $delivery_time[] = [
            'range' => $range,
            'count' => $count
        ];
    }
} catch (PDOException $e) {
    $error_message = '获取配送时间数据失败: ' . $e->getMessage();
}

// 按支付方式统计
$payment_methods = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            op.payment_type,
            CASE 
                WHEN op.payment_type = 1 THEN '现金'
                WHEN op.payment_type = 2 THEN '微信'
                WHEN op.payment_type = 3 THEN '支付宝'
                WHEN op.payment_type = 4 THEN '信用卡'
                WHEN op.payment_type = 5 THEN '储值余额'
                WHEN op.payment_type = 6 THEN '积分抵扣'
                ELSE CONCAT('其他(', op.payment_type, ')')
            END as method_name,
            COUNT(*) as count,
            SUM(op.amount) as total_amount,
            ROUND(COUNT(*) * 100 / (
                SELECT COUNT(*) FROM order_payments 
                WHERE create_time BETWEEN ? AND ?
            ), 1) as percentage
        FROM order_payments op
        WHERE op.create_time BETWEEN ? AND ?
        GROUP BY op.payment_type, method_name
        ORDER BY count DESC
    ");
    $stmt->execute([$start_date . ' 00:00:00', $end_date . ' 23:59:59', $start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $payment_methods = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error_message = '获取支付方式统计数据失败: ' . $e->getMessage();
}

// 准备图表数据
// 订单趋势图表数据
$trend_periods = [];
$trend_counts = [];
$trend_amounts = [];

foreach ($order_trend as $item) {
    $trend_periods[] = $item['period'];
    $trend_counts[] = $item['order_count'];
    $trend_amounts[] = $item['order_amount'];
}

$trend_periods_json = json_encode($trend_periods);
$trend_counts_json = json_encode($trend_counts);
$trend_amounts_json = json_encode($trend_amounts);

// 退款率趋势图表数据
$refund_periods = [];
$refund_rates = [];

foreach ($refund_trend as $item) {
    $refund_periods[] = $item['period'];
    $refund_rates[] = $item['refund_rate'];
}

$refund_periods_json = json_encode($refund_periods);
$refund_rates_json = json_encode($refund_rates);

// 订单状态分布图表数据
$status_names = [];
$status_counts = [];

foreach ($order_status as $item) {
    $status_names[] = $item['status_name'];
    $status_counts[] = $item['count'];
}

$status_names_json = json_encode($status_names);
$status_counts_json = json_encode($status_counts);

// 配送时间分布图表数据
$delivery_ranges = [];
$delivery_counts = [];

foreach ($delivery_time as $item) {
    $delivery_ranges[] = $item['range'];
    $delivery_counts[] = $item['count'];
}

$delivery_ranges_json = json_encode($delivery_ranges);
$delivery_counts_json = json_encode($delivery_counts);
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单数据分析 - FloraEase花店管理系统</title>
    <link rel="stylesheet" href="../style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单数据分析</h2>
            <div class="breadcrumb">
                <a href="index.php">数据统计与分析</a> / 订单数据
            </div>
        </div>

        <div class="content">
            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger">
                    <?php echo $error_message; ?>
                </div>
            <?php endif; ?>

            <!-- 日期筛选 -->
            <div class="filter-form">
                <form method="get" action="order.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="date_range">时间范围</label>
                            <select id="date_range" name="date_range" onchange="toggleCustomDateFields()">
                                <option value="today" <?php echo $date_range == 'today' ? 'selected' : ''; ?>>今日</option>
                                <option value="yesterday" <?php echo $date_range == 'yesterday' ? 'selected' : ''; ?>>昨日</option>
                                <option value="week" <?php echo $date_range == 'week' ? 'selected' : ''; ?>>近7天</option>
                                <option value="month" <?php echo $date_range == 'month' ? 'selected' : ''; ?>>近30天</option>
                                <option value="quarter" <?php echo $date_range == 'quarter' ? 'selected' : ''; ?>>近90天</option>
                                <option value="year" <?php echo $date_range == 'year' ? 'selected' : ''; ?>>近一年</option>
                                <option value="custom" <?php echo $date_range == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="filter-item custom-date" style="display: <?php echo $date_range == 'custom' ? 'block' : 'none'; ?>;">
                            <label for="custom_start">开始日期</label>
                            <input type="date" id="custom_start" name="custom_start" value="<?php echo $custom_start; ?>">
                        </div>
                        <div class="filter-item custom-date" style="display: <?php echo $date_range == 'custom' ? 'block' : 'none'; ?>;">
                            <label for="custom_end">结束日期</label>
                            <input type="date" id="custom_end" name="custom_end" value="<?php echo $custom_end; ?>">
                        </div>
                        <div class="filter-item">
                            <label for="period_type">趋势周期</label>
                            <select id="period_type" name="period_type">
                                <option value="day" <?php echo $period_type == 'day' ? 'selected' : ''; ?>>按日</option>
                                <option value="week" <?php echo $period_type == 'week' ? 'selected' : ''; ?>>按周</option>
                                <option value="month" <?php echo $period_type == 'month' ? 'selected' : ''; ?>>按月</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">查询</button>
                        <a href="order.php" class="btn btn-secondary">重置</a>
                    </div>
                </form>
            </div>

            <!-- 订单概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>订单总量</h3>
                    <div class="number"><?php echo number_format($order_overview['total']); ?></div>
                    <div class="desc">完成订单: <?php echo number_format($order_overview['completed']); ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>退款率</h3>
                    <div class="number"><?php echo $order_overview['refund_rate']; ?>%</div>
                    <div class="desc">退款订单: <?php echo number_format($order_overview['refunded']); ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>平均客单价</h3>
                    <div class="number">￥<?php echo number_format($order_overview['avg_amount'], 2); ?></div>
                    <div class="desc">统计范围: <?php echo $start_date; ?> 至 <?php echo $end_date; ?></div>
                </div>
            </div>

            <!-- 订单数量趋势 -->
            <div class="section">
                <h2>订单数量趋势</h2>
                <div class="chart-container" style="position: relative; height:300px;">
                    <canvas id="orderTrendChart"></canvas>
                </div>
            </div>

            <!-- 退款率趋势 -->
            <div class="section">
                <h2>退款率趋势</h2>
                <div class="chart-container" style="position: relative; height:300px;">
                    <canvas id="refundRateChart"></canvas>
                </div>
            </div>

            <!-- 订单状态分布 -->
            <div class="section">
                <h2>订单状态分布</h2>
                <div class="row">
                    <div class="chart-container" style="position: relative; height:300px; width:50%; float:left;">
                        <canvas id="orderStatusChart"></canvas>
                    </div>
                    <div class="table-container" style="width:50%; float:left;">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>订单状态</th>
                                    <th>订单数量</th>
                                    <th>占比</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (!empty($order_status)): ?>
                                    <?php foreach ($order_status as $status): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($status['status_name']); ?></td>
                                            <td><?php echo number_format($status['count']); ?></td>
                                            <td><?php echo $status['percentage']; ?>%</td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="3" class="text-center">暂无数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                    <div style="clear:both;"></div>
                </div>
            </div>

            <!-- 退款原因分析 -->
            <div class="section">
                <h2>退款原因分析</h2>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>退款原因</th>
                                <th>退款数量</th>
                                <th>占比</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($refund_reasons)): ?>
                                <?php foreach ($refund_reasons as $reason): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($reason['refund_reason'] ?: '未填写原因'); ?></td>
                                        <td><?php echo number_format($reason['count']); ?></td>
                                        <td><?php echo $reason['percentage']; ?>%</td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="3" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <!-- 配送时间分析 -->
            <div class="section">
                <h2>配送时间分析</h2>
                <div class="row">
                    <div class="chart-container" style="position: relative; height:300px; width:50%; float:left;">
                        <canvas id="deliveryTimeChart"></canvas>
                    </div>
                    <div class="table-container" style="width:50%; float:left;">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>配送时间</th>
                                    <th>订单数量</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (!empty($delivery_time)): ?>
                                    <?php foreach ($delivery_time as $time): ?>
                                        <tr>
                                            <td><?php echo $time['range']; ?></td>
                                            <td><?php echo number_format($time['count']); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="2" class="text-center">暂无数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                    <div style="clear:both;"></div>
                </div>
            </div>

            <!-- 支付方式分析 -->
            <div class="section">
                <h2>支付方式分析</h2>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>支付方式</th>
                                <th>订单数量</th>
                                <th>支付金额</th>
                                <th>占比</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($payment_methods)): ?>
                                <?php foreach ($payment_methods as $method): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($method['method_name']); ?></td>
                                        <td><?php echo number_format($method['count']); ?></td>
                                        <td>￥<?php echo number_format($method['total_amount'], 2); ?></td>
                                        <td><?php echo $method['percentage']; ?>%</td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="4" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    <script>
        // 控制自定义日期字段的显示与隐藏
        function toggleCustomDateFields() {
            var dateRange = document.getElementById('date_range').value;
            var customDateFields = document.querySelectorAll('.custom-date');

            for (var i = 0; i < customDateFields.length; i++) {
                customDateFields[i].style.display = dateRange === 'custom' ? 'block' : 'none';
            }
        }

        // 绘制订单数量趋势图
        var ctx1 = document.getElementById('orderTrendChart').getContext('2d');
        var orderTrendChart = new Chart(ctx1, {
            type: 'line',
            data: {
                labels: <?php echo $trend_periods_json; ?>,
                datasets: [{
                    label: '订单数量',
                    data: <?php echo $trend_counts_json; ?>,
                    backgroundColor: 'rgba(54, 162, 235, 0.2)',
                    borderColor: 'rgba(54, 162, 235, 1)',
                    borderWidth: 1,
                    tension: 0.4,
                    yAxisID: 'y'
                }, {
                    label: '订单金额',
                    data: <?php echo $trend_amounts_json; ?>,
                    backgroundColor: 'rgba(255, 159, 64, 0.2)',
                    borderColor: 'rgba(255, 159, 64, 1)',
                    borderWidth: 1,
                    tension: 0.4,
                    yAxisID: 'y1'
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        position: 'left',
                        title: {
                            display: true,
                            text: '订单数量'
                        }
                    },
                    y1: {
                        beginAtZero: true,
                        position: 'right',
                        title: {
                            display: true,
                            text: '订单金额（元）'
                        },
                        grid: {
                            drawOnChartArea: false
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '时间'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '订单数量与金额趋势'
                    }
                }
            }
        });

        // 绘制退款率趋势图
        var ctx2 = document.getElementById('refundRateChart').getContext('2d');
        var refundRateChart = new Chart(ctx2, {
            type: 'line',
            data: {
                labels: <?php echo $refund_periods_json; ?>,
                datasets: [{
                    label: '退款率(%)',
                    data: <?php echo $refund_rates_json; ?>,
                    backgroundColor: 'rgba(255, 99, 132, 0.2)',
                    borderColor: 'rgba(255, 99, 132, 1)',
                    borderWidth: 1,
                    tension: 0.4
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '退款率(%)'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '时间'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '退款率趋势'
                    }
                }
            }
        });

        // 绘制订单状态分布图
        var ctx3 = document.getElementById('orderStatusChart').getContext('2d');
        var orderStatusChart = new Chart(ctx3, {
            type: 'doughnut',
            data: {
                labels: <?php echo $status_names_json; ?>,
                datasets: [{
                    data: <?php echo $status_counts_json; ?>,
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.7)',
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)',
                        'rgba(75, 192, 192, 0.7)',
                        'rgba(153, 102, 255, 0.7)',
                        'rgba(255, 159, 64, 0.7)',
                        'rgba(201, 203, 207, 0.7)',
                        'rgba(255, 99, 71, 0.7)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        position: 'right'
                    },
                    title: {
                        display: true,
                        text: '订单状态分布'
                    }
                }
            }
        });

        // 绘制配送时间分析图
        var ctx4 = document.getElementById('deliveryTimeChart').getContext('2d');
        var deliveryTimeChart = new Chart(ctx4, {
            type: 'bar',
            data: {
                labels: <?php echo $delivery_ranges_json; ?>,
                datasets: [{
                    label: '订单数量',
                    data: <?php echo $delivery_counts_json; ?>,
                    backgroundColor: 'rgba(75, 192, 192, 0.7)',
                    borderColor: 'rgba(75, 192, 192, 1)',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '订单数量'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '配送时间范围'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '配送时间分布'
                    }
                }
            }
        });
    </script>
</body>

</html>