<?php
// store/employee.php - 员工管理
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('store.view');

// 处理操作请求
$action = isset($_GET['action']) ? $_GET['action'] : 'list';
$message = '';
$messageType = '';

// 处理员工添加
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'add') {
    // 检查添加权限
    check_permission_or_die('store.add');

    $store_id = $_POST['store_id'] ?? '';
    $name = $_POST['name'] ?? '';
    $position = $_POST['position'] ?? '';
    $phone = $_POST['phone'] ?? '';
    $entry_date = $_POST['entry_date'] ?? '';
    $status = isset($_POST['status']) ? 1 : 0;

    if (empty($store_id) || empty($name) || empty($position) || empty($phone) || empty($entry_date)) {
        $message = '请填写所有必填字段';
        $messageType = 'danger';
    } else {
        try {
            $stmt = $pdo->prepare("INSERT INTO employees (store_id, name, position, phone, entry_date, status) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([$store_id, $name, $position, $phone, $entry_date, $status]);

            record_log("添加员工: $name");
            $message = '员工添加成功';
            $messageType = 'success';
            $action = 'list'; // 返回列表视图
        } catch (PDOException $e) {
            $message = '员工添加失败: ' . $e->getMessage();
            $messageType = 'danger';
        }
    }
}

// 处理员工更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $action === 'edit') {
    // 检查编辑权限
    check_permission_or_die('store.edit');

    $id = $_POST['id'] ?? 0;
    $store_id = $_POST['store_id'] ?? '';
    $name = $_POST['name'] ?? '';
    $position = $_POST['position'] ?? '';
    $phone = $_POST['phone'] ?? '';
    $entry_date = $_POST['entry_date'] ?? '';
    $status = isset($_POST['status']) ? 1 : 0;

    if (empty($id) || empty($store_id) || empty($name) || empty($position) || empty($phone) || empty($entry_date)) {
        $message = '请填写所有必填字段';
        $messageType = 'danger';
    } else {
        try {
            $stmt = $pdo->prepare("UPDATE employees SET store_id = ?, name = ?, position = ?, phone = ?, entry_date = ?, status = ? WHERE id = ?");
            $stmt->execute([$store_id, $name, $position, $phone, $entry_date, $status, $id]);

            record_log("更新员工: $name (ID: $id)");
            $message = '员工更新成功';
            $messageType = 'success';
            $action = 'list'; // 返回列表视图
        } catch (PDOException $e) {
            $message = '员工更新失败: ' . $e->getMessage();
            $messageType = 'danger';
        }
    }
}

// 处理员工删除
if ($action === 'delete' && isset($_GET['id'])) {
    // 检查删除权限
    check_permission_or_die('store.delete');

    $id = $_GET['id'];

    try {
        $stmt = $pdo->prepare("DELETE FROM employees WHERE id = ?");
        $stmt->execute([$id]);

        record_log("删除员工 (ID: $id)");
        $message = '员工删除成功';
        $messageType = 'success';
    } catch (PDOException $e) {
        $message = '员工删除失败: ' . $e->getMessage();
        $messageType = 'danger';
    }
    $action = 'list'; // 返回列表视图
}

// 获取单个员工信息（用于编辑和查看）
$employeeInfo = null;
if (($action === 'edit' || $action === 'view') && isset($_GET['id'])) {
    $id = $_GET['id'];
    try {
        $stmt = $pdo->prepare("SELECT e.*, s.name as store_name FROM employees e LEFT JOIN stores s ON e.store_id = s.id WHERE e.id = ?");
        $stmt->execute([$id]);
        $employeeInfo = $stmt->fetch();

        if (!$employeeInfo) {
            $message = '员工不存在';
            $messageType = 'danger';
            $action = 'list'; // 返回列表视图
        }
    } catch (PDOException $e) {
        $message = '获取员工信息失败: ' . $e->getMessage();
        $messageType = 'danger';
        $action = 'list'; // 返回列表视图
    }
}

// 获取门店列表（用于选择门店）
$storesList = [];
try {
    $stmt = $pdo->query("SELECT id, name FROM stores ORDER BY id");
    $storesList = $stmt->fetchAll();
} catch (PDOException $e) {
    $message = '获取门店列表失败: ' . $e->getMessage();
    $messageType = 'danger';
}

// 获取员工列表（用于列表视图）
$employees = [];
if ($action === 'list') {
    // 分页参数
    $page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
    $limit = 10;
    $offset = ($page - 1) * $limit;

    // 搜索条件
    $searchName = isset($_GET['search_name']) ? $_GET['search_name'] : '';
    $searchStore = isset($_GET['search_store']) ? $_GET['search_store'] : '';
    $searchStatus = isset($_GET['search_status']) ? $_GET['search_status'] : '';

    $where = [];
    $params = [];

    if (!empty($searchName)) {
        $where[] = "e.name LIKE ?";
        $params[] = "%$searchName%";
    }

    if (!empty($searchStore)) {
        $where[] = "e.store_id = ?";
        $params[] = $searchStore;
    }

    if ($searchStatus !== '') {
        $where[] = "e.status = ?";
        $params[] = $searchStatus;
    }

    $whereClause = empty($where) ? "" : "WHERE " . implode(" AND ", $where);

    // 获取总记录数
    $countSql = "SELECT COUNT(*) as total FROM employees e $whereClause";
    $stmt = $pdo->prepare($countSql);
    $stmt->execute($params);
    $totalRecords = $stmt->fetch()['total'];
    $totalPages = ceil($totalRecords / $limit);

    // 获取分页数据
    $sql = "SELECT e.*, s.name as store_name FROM employees e 
            LEFT JOIN stores s ON e.store_id = s.id 
            $whereClause 
            ORDER BY e.id DESC LIMIT $offset, $limit";
    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $employees = $stmt->fetchAll();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>员工管理 - FloraEase</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>员工管理</h2>
            <div class="breadcrumb">
                <a href="index.php">门店管理</a> / 员工管理
            </div>
        </div>

        <div class="content">
            <?php if (!empty($message)): ?>
                <div class="alert alert-<?php echo $messageType; ?>">
                    <?php echo $message; ?>
                </div>
            <?php endif; ?>

            <?php if ($action === 'list'): ?>
                <!-- 操作栏 -->
                <div class="action-bar">
                    <?php if (has_permission('store.add')): ?>
                        <a href="?action=add" class="btn btn-primary">添加员工</a>
                    <?php endif; ?>
                </div>

                <!-- 搜索表单 -->
                <form method="get" action="employee.php" class="filter-form">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="search_name">员工姓名</label>
                            <input type="text" id="search_name" name="search_name" value="<?php echo htmlspecialchars($searchName ?? ''); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="search_store">所属门店</label>
                            <select id="search_store" name="search_store">
                                <option value="">全部门店</option>
                                <?php foreach ($storesList as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo $searchStore == $store['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="search_status">状态</label>
                            <select id="search_status" name="search_status">
                                <option value="">全部</option>
                                <option value="1" <?php echo $searchStatus === '1' ? 'selected' : ''; ?>>在职</option>
                                <option value="0" <?php echo $searchStatus === '0' ? 'selected' : ''; ?>>离职</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">搜索</button>
                        <a href="?action=list" class="btn btn-secondary">重置</a>
                    </div>
                </form>

                <!-- 员工列表 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>姓名</th>
                                <th>所属门店</th>
                                <th>职位</th>
                                <th>联系电话</th>
                                <th>入职日期</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($employees as $employee): ?>
                                <tr>
                                    <td><?php echo $employee['id']; ?></td>
                                    <td><?php echo htmlspecialchars($employee['name']); ?></td>
                                    <td><?php echo htmlspecialchars($employee['store_name']); ?></td>
                                    <td><?php echo htmlspecialchars($employee['position']); ?></td>
                                    <td><?php echo htmlspecialchars($employee['phone']); ?></td>
                                    <td><?php echo $employee['entry_date']; ?></td>
                                    <td>
                                        <?php if ($employee['status'] == 1): ?>
                                            <span class="status-active">在职</span>
                                        <?php else: ?>
                                            <span class="status-inactive">离职</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <a href="?action=view&id=<?php echo $employee['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                        <?php if (has_permission('store.edit')): ?>
                                            <a href="?action=edit&id=<?php echo $employee['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                        <?php endif; ?>
                                        <?php if (has_permission('store.delete')): ?>
                                            <a href="?action=delete&id=<?php echo $employee['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此员工吗？')">删除</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (empty($employees)): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无员工数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($totalPages > 1): ?>
                    <div class="pagination">
                        <?php if ($page > 1): ?>
                            <a href="?action=list&page=1<?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">首页</a>
                            <a href="?action=list&page=<?php echo $page - 1; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">上一页</a>
                        <?php endif; ?>

                        <?php
                        $startPage = max(1, $page - 2);
                        $endPage = min($totalPages, $page + 2);

                        for ($i = $startPage; $i <= $endPage; $i++):
                        ?>
                            <a href="?action=list&page=<?php echo $i; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link <?php echo $i == $page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                        <?php endfor; ?>

                        <?php if ($page < $totalPages): ?>
                            <a href="?action=list&page=<?php echo $page + 1; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">下一页</a>
                            <a href="?action=list&page=<?php echo $totalPages; ?><?php echo !empty($searchName) ? '&search_name=' . urlencode($searchName) : ''; ?><?php echo !empty($searchStore) ? '&search_store=' . $searchStore : ''; ?><?php echo $searchStatus !== '' ? '&search_status=' . $searchStatus : ''; ?>" class="page-link">末页</a>
                        <?php endif; ?>
                    </div>
                    <div class="pagination-info">
                        共 <?php echo $totalRecords; ?> 条记录，当前 <?php echo $page; ?>/<?php echo $totalPages; ?> 页
                    </div>
                <?php endif; ?>

            <?php elseif ($action === 'add' || $action === 'edit'): ?>
                <!-- 添加/编辑员工表单 -->
                <form method="post" action="?action=<?php echo $action; ?>" class="form-container">
                    <h3><?php echo $action === 'add' ? '添加员工' : '编辑员工'; ?></h3>

                    <?php if ($action === 'edit'): ?>
                        <input type="hidden" name="id" value="<?php echo $employeeInfo['id']; ?>">
                    <?php endif; ?>

                    <div class="form-group">
                        <label for="store_id">所属门店 *</label>
                        <select id="store_id" name="store_id" required>
                            <option value="">请选择门店</option>
                            <?php foreach ($storesList as $store): ?>
                                <option value="<?php echo $store['id']; ?>" <?php echo ($action === 'edit' && $employeeInfo['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($store['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="name">员工姓名 *</label>
                        <input type="text" id="name" name="name" value="<?php echo $action === 'edit' ? htmlspecialchars($employeeInfo['name']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="position">职位 *</label>
                        <input type="text" id="position" name="position" value="<?php echo $action === 'edit' ? htmlspecialchars($employeeInfo['position']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="phone">联系电话 *</label>
                        <input type="text" id="phone" name="phone" value="<?php echo $action === 'edit' ? htmlspecialchars($employeeInfo['phone']) : ''; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="entry_date">入职日期 *</label>
                        <input type="date" id="entry_date" name="entry_date" value="<?php echo $action === 'edit' ? $employeeInfo['entry_date'] : date('Y-m-d'); ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="status">状态</label>
                        <div class="checkbox-item">
                            <label>
                                <input type="checkbox" id="status" name="status" value="1" <?php echo $action === 'edit' && $employeeInfo['status'] == 1 ? 'checked' : ''; ?>> 在职
                            </label>
                        </div>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary"><?php echo $action === 'add' ? '添加' : '保存'; ?></button>
                        <a href="?action=list" class="btn btn-secondary">取消</a>
                    </div>
                </form>

            <?php elseif ($action === 'view'): ?>
                <!-- 员工详情 -->
                <div class="form-container">
                    <h3>员工详情</h3>

                    <table class="info-table">
                        <tr>
                            <td width="20%">员工ID：</td>
                            <td><?php echo $employeeInfo['id']; ?></td>
                        </tr>
                        <tr>
                            <td>员工姓名：</td>
                            <td><?php echo htmlspecialchars($employeeInfo['name']); ?></td>
                        </tr>
                        <tr>
                            <td>所属门店：</td>
                            <td><?php echo htmlspecialchars($employeeInfo['store_name']); ?></td>
                        </tr>
                        <tr>
                            <td>职位：</td>
                            <td><?php echo htmlspecialchars($employeeInfo['position']); ?></td>
                        </tr>
                        <tr>
                            <td>联系电话：</td>
                            <td><?php echo htmlspecialchars($employeeInfo['phone']); ?></td>
                        </tr>
                        <tr>
                            <td>入职日期：</td>
                            <td><?php echo $employeeInfo['entry_date']; ?></td>
                        </tr>
                        <tr>
                            <td>状态：</td>
                            <td><?php echo $employeeInfo['status'] == 1 ? '<span class="status-active">在职</span>' : '<span class="status-inactive">离职</span>'; ?></td>
                        </tr>
                    </table>

                    <div class="form-actions">
                        <?php if (has_permission('store.edit')): ?>
                            <a href="?action=edit&id=<?php echo $employeeInfo['id']; ?>" class="btn btn-primary">编辑</a>
                        <?php endif; ?>
                        <a href="?action=list" class="btn btn-secondary">返回</a>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>